@@ -12,7 +12,7 @@ cp debian/tests/source-data/"$INPUT_PAYLOAD" "${RAVEN_TMP}/"
 cd "$RAVEN_TMP"
 
 # Start Raven and perform upload
-raven 127.0.0.1 "$PORT" --upload-folder "$RAVEN_TMP" --organize-uploads & sleep 5
+raven 127.0.0.1 "$PORT" --upload-dir "$RAVEN_TMP" --organize-uploads & sleep 5
 
 if pgrep -x "raven" >/dev/null; then
     echo "Raven started successfully."
@@ -29,8 +29,8 @@ if [[ $? -ne 0 ]]; then
     exit 1
 fi
 
-# Normalize line endings and remove trailing empty lines from remote payload
-dos2unix -q "$REMOTE_PAYLOAD" && sed -i '${/^$/d}' "$REMOTE_PAYLOAD"
+# Normalize line endings
+dos2unix -q "$REMOTE_PAYLOAD"
 
 # Compare the original payload with the remote payload
 diff "$INPUT_PAYLOAD" "$REMOTE_PAYLOAD" >/dev/null
